( cd opt/kde/share/doc/HTML/pt_BR/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/ark ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kdm ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kate ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kdvi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kppp ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kxkb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/katomic ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/ksysguard ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kbattleship ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/cervisia ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kdesu ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcron ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kfind ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/klipper ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kompare ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/konsole ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/konquest ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kioslave ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/pt_BR/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kbabel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kamera ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kdeprint ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kasteroids ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/keduca ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kpager ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kspell ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kstars ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kwrite ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kreversi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/ksplashml ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kblackbox ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcharselect ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/quanta ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/umbrello ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/konqueror ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/atlantik ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
